@@ -82,7 +82,7 @@ textmodel_ca.dfm <- function(x, smooth = 0, nd = NA, sparse = FALSE,
         S  <- (P - eP) / sqrt(eP)
     } else {
         # keep the residual matrix sparse
-        S <- as(qatd_cpp_ca(P, residual_floor / sqrt(n)), "CsparseMatrix")
+        S <- as(cpp_ca(P, residual_floor / sqrt(n)), "CsparseMatrix")
     }
 
     dec <- RSpectra::svds(S, nd)
