@@ -1,5 +1,3 @@
-context("test default methods for nice error messages")
-
 test_that("test default textmodel methods", {
     expect_error(
         textmodel_affinity(TRUE, FALSE),
@@ -13,6 +11,14 @@ test_that("test default textmodel methods", {
         textmodel_nb(TRUE),
         "textmodel_nb\\(\\) only works on dfm.*objects"
     )
+    expect_error(
+        textmodel_svm(TRUE),
+        "textmodel_svm\\(\\) only works on dfm.*objects"
+    )
+    expect_error(
+        textmodel_svmlin(TRUE),
+        "textmodel_svmlin\\(\\) only works on dfm.*objects"
+    )
     expect_error(
         textmodel_wordfish(TRUE),
         "textmodel_wordfish\\(\\) only works on dfm.*objects"
@@ -28,8 +34,4 @@ test_that("test default textplot methods", {
         textplot_influence(TRUE),
         "textplot_influence\\(\\) only works on influence\\..*textmodel_affinity objects"
     )
-    expect_error(
-        textplot_scale1d(TRUE),
-        "textplot_scale1d\\(\\) only works on predict\\.textmodel.*objects"
-    )
 })
